==> vradi-swing-0.0.3-sources.jar: com/jurismarches/vradi/models/FieldTypeModel.java <==
/*
 * *##% 
 * vradi-swing
 * Copyright (C) 2009 JurisMarches
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * ##%*
 */
/*
* @(#)DefaultComboBoxModel.java	1.20 05/11/17
*
* Copyright 2006 Sun Microsystems, Inc. All rights reserved.
* SUN PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
*/
package com.jurismarches.vradi.models;

import com.jurismarches.vradi.entities.FieldTypeEnum;

import javax.swing.*;


/**
 * @author letellier
 */
public class FieldTypeModel extends AbstractListModel implements MutableComboBoxModel {

    private static final long serialVersionUID = 1L;

    protected FieldTypeEnum selected = null;
    protected FieldTypeEnum[] values = FieldTypeEnum.values();

    @Override
    public int getSize() {
        return values.length;
    }

    @Override
    public Object getElementAt(int index) {
        return values[index];
    }

    @Override
    public void addElement(Object obj) {
    }

    @Override
    public void removeElement(Object obj) {
    }

    @Override
    public void insertElementAt(Object obj, int index) {
    }

    @Override
    public void removeElementAt(int index) {
    }

    @Override
    public void setSelectedItem(Object anItem) {
        selected = (FieldTypeEnum) anItem;
    }

    @Override
    public Object getSelectedItem() {
        return selected;
    }

}

==> vradi-swing-0.0.4-sources.jar: com/jurismarches/vradi/models/FieldTypeModel.java <==
/*
 * *##%
 * Vradi :: Swing
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * ##%*
 */
package com.jurismarches.vradi.models;

import javax.swing.AbstractListModel;
import javax.swing.MutableComboBoxModel;

import com.jurismarches.vradi.entities.FieldTypeEnum;

/**
 * @author letellier
 */
public class FieldTypeModel extends AbstractListModel implements MutableComboBoxModel {

    private static final long serialVersionUID = 1L;

    protected FieldTypeEnum selected = null;
    protected FieldTypeEnum[] values = FieldTypeEnum.values();

    @Override
    public int getSize() {
        return values.length;
    }

    @Override
    public Object getElementAt(int index) {
        return values[index];
    }

    @Override
    public void addElement(Object obj) {
    }

    @Override
    public void removeElement(Object obj) {
    }

    @Override
    public void insertElementAt(Object obj, int index) {
    }

    @Override
    public void removeElementAt(int index) {
    }

    @Override
    public void setSelectedItem(Object anItem) {
        selected = (FieldTypeEnum) anItem;
    }

    @Override
    public Object getSelectedItem() {
        return selected;
    }

}
